pub enum ClipTab {
InstConfig,
PianoRoll,
Settings,
Sequencer,
}Expand description
Tab in the piano roll / clip area (right side of clip view).
Variants
InstConfig
PianoRoll
Settings
Sequencer
The step grid. Only reachable on a track that has a sequencer on it —
ClipTab::next steps over it everywhere else, and the tab strip
leaves it out.
Implementations