TrackState

Struct TrackState 

pub struct TrackState {
Show 13 fields pub name: String, pub muted: bool, pub soloed: bool, pub armed: bool, pub color_index: usize, pub kind: TrackKind, pub clips: Vec<Clip>, pub fx_chain: Vec<FxInstance>, pub volume: f32, pub mixer_id: Option<usize>, pub handle: Option<Arc<TrackHandle>>, pub instrument_type: Option<InstrumentType>, pub synth_params: Vec<f32>,
}

Fields

name: Stringmuted: boolsoloed: boolarmed: boolcolor_index: usizekind: TrackKindclips: Vec<Clip>fx_chain: Vec<FxInstance>

Track-level FX chain.

volume: f32

Track volume (0.0..1.0).

mixer_id: Option<usize>

Unique ID for this track (matches the mixer’s track ID).

handle: Option<Arc<TrackHandle>>

Handle to the audio engine’s track state. When present, mute/solo/arm/volume writes go directly to the audio thread via atomics.

instrument_type: Option<InstrumentType>

What type of instrument this track has.

synth_params: Vec<f32>

Parameter values (mirrors the audio thread’s plugin params).

Implementations

Source

impl TrackState

pub fn new( name: &str, color_index: usize, armed: bool, kind: TrackKind, clips: Vec<Clip>, ) -> Self

pub fn sync_to_audio(&self)

Sync mute/solo/arm/volume to the audio thread handle (if wired up).

pub fn vu_levels(&self) -> (f32, f32)

Read VU levels from the audio thread handle.

pub fn is_live(&self) -> bool

Whether this track is wired to the audio engine.