pub enum GridResolution {
Quarter,
Eighth,
Sixteenth,
ThirtySecond,
QuarterT,
EighthT,
SixteenthT,
}Variants
Implementations
Sourceimpl GridResolution
impl GridResolution
Sourcepub fn subdivisions_per_beat(self) -> f64
pub fn subdivisions_per_beat(self) -> f64
Fraction of a bar (4/4 time, 1 bar = column_count columns). This returns fraction relative to the full clip (0.0..1.0) when multiplied by (beats_per_bar / total_beats).
Sourcepub fn step_frac(self, total_beats: usize) -> f64
pub fn step_frac(self, total_beats: usize) -> f64
Grid step as a fraction of the total clip, given total beats.
Sourcepub fn snap(self, frac: f64, total_beats: usize) -> f64
pub fn snap(self, frac: f64, total_beats: usize) -> f64
Snap a fractional position to the nearest grid line.
pub fn label(self) -> &'static str
pub fn next(self) -> Self
pub fn prev(self) -> Self